All Classes and Interfaces
Class
Description
Abstract class for convenience implementation of
ModuleExtractors able of precomputing
global axioms and tautologies.An abstract debugger which provides common infrastructure for finding
multiple justification.
Orders an explanation in a flat list, sorting axioms alphabetically.
a multimap for int to collection of int values.
An atom in the atomic decomposition
Class to represent the atomic decomposition of a set of axioms.
The atomic decomposition graph
Atomic decomposition implementation.
Atomic ontology structure.
A filter for axioms
Wrapper around an OWLAxiom to hold attributes such as used, included in a module, included in
search space and atom which contains it.
A black box explanation.
This is an implementation of a black box debugger.
check whether class expressions are equivalent to bottom wrt given locality class
Explanation renderer in concise form.
Atomic decomposer for an ontology.
Tracker for definitions.
a generator for explanations.
Provides ordering and indenting of explanations based on various ordering heuristics.
Provides ordering and indenting of explanations based on various ordering heuristics.
A progress monitor for an explanation generator.
Renderer for explanations.
sorted set of ints.
factory for int sets
Counts the number of "hidden" GCIs in an ontology imports closure.
HST explanation generator.
An
OWLMetric that returns an integer value.Types of locality classes that can be used.
Types of locality classes that can be used.
A locality evaluator.
Interface for classes that test whether an axiom is local with respect to a signature.
Abstract class for convenience implementation of locality-based
ModuleExtractors.class to create modules of an ontology wrt module type
class to create modules of an ontology wrt module type
Interface for classes that extract modules based on fixed axiom bases.
Module types - for use with Chiara and Dmitry's implementation of
modularisation and atomic decomposition, as implemented in
FaCT++/OWLAPITOOLS.
Enumeration for module types.
multiple explanation generator.
An implementation of an explanation order, which doesn't really do any
ordering!.
An ontology atom including module and dependencies information.
Ontology based modularizer.
An interface for any class implementing ontology segmentation or modularisation.
Some ontology utils methods.
Represents a metric about some aspect of an ontology and possibly its imports closure.
Extracts the parts of a class expression which are negated.
Satisfiability converter.
semantic locality checker for DL axioms
Semantic locality evaluator.
Thread safe class for checking semantic locality.
Class to extract modules based on semantic locality.
helper class to set signature and locality class
signature index
class to hold the signature of a module
The Class SilentExplanationProgressMonitor.
Null implementation.
Explanation generator for a single explanation.
The Class SingleExplanationGeneratorImpl.
syntactic locality checker for DL axioms
Syntactic locality evaluator.
Thread safe class for checking syntactic locality.
Class to extract modules based on syntactic locality.
Implementation of module extraction based on syntactic locality.
check whether class expressions are equivalent to top wrt given locality class
transactional support for single explanation generator.