Package org.semanticweb.owlapi.debugging
Class AbstractOWLDebugger
java.lang.Object
org.semanticweb.owlapi.debugging.AbstractOWLDebugger
- All Implemented Interfaces:
OWLDebugger
- Direct Known Subclasses:
BlackBoxOWLDebugger
An abstract debugger which provides common infrastructure for finding
multiple justification. This functionality relies on a concrete
implementation of a debugger that can compute a minimal set of axioms that
cause the unsatisfiability.
- Since:
- 2.0.0
- Author:
- Matthew Horridge, The University Of Manchester, Bio-Health Informatics Group
-
Method Summary
Modifier and TypeMethodDescriptionvoidconstructHittingSetTree(Set<OWLAxiom> mups, Set<Set<OWLAxiom>> allMups, Set<Set<OWLAxiom>> satPaths, Set<OWLAxiom> currentPathContents) This is a recursive method that builds a hitting set tree to obtain all justifications for an unsatisfiable class.Get all SOS for inconsistent class.Gets the ontology.Methods inherited from class java.lang.Object
equals, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.semanticweb.owlapi.debugging.OWLDebugger
dispose, getSOSForInconsistentClass
-
Method Details
-
getOWLOntology
Description copied from interface:OWLDebuggerGets the ontology.- Specified by:
getOWLOntologyin interfaceOWLDebugger- Returns:
- the
OWLOntologythat is being debugged.
-
getAllSOSForInconsistentClass
Description copied from interface:OWLDebuggerGet all SOS for inconsistent class.- Specified by:
getAllSOSForInconsistentClassin interfaceOWLDebugger- Parameters:
cls- the inconsistent class- Returns:
- all sets of supporting axioms that are responsible for the specified class being inconsistent
- Throws:
OWLException- if there is any problem
-
constructHittingSetTree
public void constructHittingSetTree(Set<OWLAxiom> mups, Set<Set<OWLAxiom>> allMups, Set<Set<OWLAxiom>> satPaths, Set<OWLAxiom> currentPathContents) throws OWLException This is a recursive method that builds a hitting set tree to obtain all justifications for an unsatisfiable class.- Parameters:
mups- The current justification for the current class. This corresponds to a node in the hitting set tree.allMups- All of the MUPS that have been found - this set gets populated over the course of the tree building process. Initially this should just contain the first justificationsatPaths- Paths that have been completed.currentPathContents- The contents of the current path. Initially this should be an empty set.- Throws:
OWLException- if there is any problem
-