Class AbstractModuleExtractor
java.lang.Object
org.semanticweb.owlapi.modularity.AbstractModuleExtractor
- All Implemented Interfaces:
ModuleExtractor
Abstract class for convenience implementation of
ModuleExtractors able of precomputing
global axioms and tautologies.- Author:
- Marc Robin Nolte
-
Method Summary
Modifier and TypeMethodDescriptionReturn the axioms all modules of this ModuleExtractor are computed against, including global axioms and tautologies.booleancontainsAxiom(OWLAxiom axiom) Returns whether the axiom base of this ModuleExtractor contains the givenOWLAxiom.final booleaneveryModuleContains(OWLAxiom axiom) Returnstrueif it is guaranteed that the givenOWLAxiomis contained in every module calculated by the module extraction method this ModuleExtractor is based on;falsewhen no such guarantee can be made (Note: This does not mean that there is some module regardless of other axioms or the signature that does not contain the given axiom).globals()Returns from the axiom base of this extractor exactly those that are guaranteed to be contained in every module calculated by this ModuleExtractor.final booleannoModuleContains(OWLAxiom axiom) Returnstrueif it is guaranteed that the givenOWLAxiomis not contained in any module (regardless of other axioms or the signature) calculated by the module extraction method this ModuleExtractor is based on;falsewhen no such guarantee can be made (Note: This does not mean that there is some module that contains the given axiom).Returns from the axiom base of this extractor exactly those that are guaranteed not to be contained in any module calculated by this ModuleExtractor.Methods inherited from class java.lang.Object
equals, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.semanticweb.owlapi.modularity.ModuleExtractor
extract, extract, extract, extractAsOntology
-
Method Details
-
axiomBase
Description copied from interface:ModuleExtractorReturn the axioms all modules of this ModuleExtractor are computed against, including global axioms and tautologies.- Specified by:
axiomBasein interfaceModuleExtractor- Returns:
- The axioms as specified above
-
containsAxiom
Description copied from interface:ModuleExtractorReturns whether the axiom base of this ModuleExtractor contains the givenOWLAxiom.- Specified by:
containsAxiomin interfaceModuleExtractor- Parameters:
axiom- The axiom to test- Returns:
- A boolean value as specified above
-
everyModuleContains
Description copied from interface:ModuleExtractorReturnstrueif it is guaranteed that the givenOWLAxiomis contained in every module calculated by the module extraction method this ModuleExtractor is based on;falsewhen no such guarantee can be made (Note: This does not mean that there is some module regardless of other axioms or the signature that does not contain the given axiom). This methods returningtrueimplies thatModuleExtractor.noModuleContains(OWLAxiom)returnsfalsefor the same axiom.- Specified by:
everyModuleContainsin interfaceModuleExtractor- Parameters:
axiom- TheOWLAxiomto check- Returns:
- A boolean value as specified above
-
globals
Description copied from interface:ModuleExtractorReturns from the axiom base of this extractor exactly those that are guaranteed to be contained in every module calculated by this ModuleExtractor. These axioms may be precomputed or calculated on every call of this method.- Specified by:
globalsin interfaceModuleExtractor- Returns:
- The axioms as specified above
-
noModuleContains
Description copied from interface:ModuleExtractorReturnstrueif it is guaranteed that the givenOWLAxiomis not contained in any module (regardless of other axioms or the signature) calculated by the module extraction method this ModuleExtractor is based on;falsewhen no such guarantee can be made (Note: This does not mean that there is some module that contains the given axiom). This methods returningtrueimplies thatModuleExtractor.everyModuleContains(OWLAxiom)returnsfalsefor the same axiom.- Specified by:
noModuleContainsin interfaceModuleExtractor- Parameters:
axiom- TheOWLAxiomto check- Returns:
- A boolean value as specified above
-
tautologies
Description copied from interface:ModuleExtractorReturns from the axiom base of this extractor exactly those that are guaranteed not to be contained in any module calculated by this ModuleExtractor. These axioms may be precomputed or calculated on every call of this method.- Specified by:
tautologiesin interfaceModuleExtractor- Returns:
- The axioms as specified above
-