Uses of Interface
org.semanticweb.owlapi.modularity.ModuleExtractor
Packages that use ModuleExtractor
Package
Description
Modularity interface package.
-
Uses of ModuleExtractor in org.semanticweb.owlapi.modularity
Classes in org.semanticweb.owlapi.modularity that implement ModuleExtractorModifier and TypeClassDescriptionclassAbstract class for convenience implementation ofModuleExtractors able of precomputing global axioms and tautologies.Constructor parameters in org.semanticweb.owlapi.modularity with type arguments of type ModuleExtractorModifierConstructorDescriptionAtomicDecomposition(Stream<OWLAxiom> axioms, Function<Stream<OWLAxiom>, ? extends ModuleExtractor> function) Constructs theAtomicDecompositionfor the given axiom base based on the module extraction theModuleExtractorthe givenFunctionsupplies.AtomicDecomposition(OWLOntology ontology, Function<Stream<OWLAxiom>, ? extends ModuleExtractor> function) Constructs theAtomicDecompositionfor the given axiom base based on the module extraction theModuleExtractorthe givenFunctionsupplies. -
Uses of ModuleExtractor in org.semanticweb.owlapi.modularity.locality
Classes in org.semanticweb.owlapi.modularity.locality that implement ModuleExtractorModifier and TypeClassDescriptionclassAbstract class for convenience implementation of locality-basedModuleExtractors.final classClass to extract modules based on semantic locality.classClass to extract modules based on syntactic locality.