Enum Class LocalityClass

java.lang.Object
java.lang.Enum<LocalityClass>
org.semanticweb.owlapi.modularity.locality.LocalityClass
All Implemented Interfaces:
Serializable, Comparable<LocalityClass>, java.lang.constant.Constable

public enum LocalityClass extends Enum<LocalityClass>
Types of locality classes that can be used. Note that although these are named after the syntactic locality classes, when used for the SemanticLocalityModuleExtractor, BOTTOM corresponds to \empty_set and TOP corresponds to \Delta.
Author:
Marc Robin Nolte
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>
  • Enum Constant Summary

    Enum Constants
    Enum Constant
    Description
    Locality module class obtained by giving concepts and roles not present in the signature empty interpretations when extracting a locality based module.
    Locality class obtained when nesting BOTTOM and TOP modules until stabilization.
    Locality module class obtained by giving concepts in the signature top concept interpretation and roles not present universal role interpretation when extracting a locality based module.
  • Method Summary

    Modifier and Type
    Method
    Description
    Returns the enum constant of this class with the specified name.
    static LocalityClass[]
    Returns an array containing the constants of this enum class, in the order they are declared.

    Methods inherited from class java.lang.Enum

    compareTo, describeConstable, equals, getDeclaringClass, hashCode, name, ordinal, toString, valueOf

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait
  • Enum Constant Details

    • BOTTOM

      public static final LocalityClass BOTTOM
      Locality module class obtained by giving concepts and roles not present in the signature empty interpretations when extracting a locality based module.
    • STAR

      public static final LocalityClass STAR
      Locality class obtained when nesting BOTTOM and TOP modules until stabilization.
    • TOP

      public static final LocalityClass TOP
      Locality module class obtained by giving concepts in the signature top concept interpretation and roles not present universal role interpretation when extracting a locality based module.
  • Method Details

    • values

      public static LocalityClass[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static LocalityClass valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null