Uses of Enum Class
org.semanticweb.owlapi.modularity.locality.LocalityClass
Packages that use LocalityClass
-
Uses of LocalityClass in org.semanticweb.owlapi.modularity.locality
Methods in org.semanticweb.owlapi.modularity.locality that return LocalityClassModifier and TypeMethodDescriptionLocalityModuleExtractor.getLocalityClass()Returns the locality class used by this LocalityModuleExtractor.static LocalityClassReturns the enum constant of this class with the specified name.static LocalityClass[]LocalityClass.values()Returns an array containing the constants of this enum class, in the order they are declared.Constructors in org.semanticweb.owlapi.modularity.locality with parameters of type LocalityClassModifierConstructorDescriptionSemanticLocalityEvaluator(LocalityClass localityClass, OWLOntologyManager ontologyManager, OWLReasonerFactory reasonerFactory) Instantiates a new SemanticLocalityEvaluator.SemanticLocalityModuleExtractor(LocalityClass localityClass, Stream<OWLAxiom> axiomBase, OWLOntologyManager ontologyManager, OWLReasonerFactory reasonerFactory) Instantiates a newSemanticLocalityEvaluator.SyntacticLocalityModuleExtractor(LocalityClass localityClass, Stream<OWLAxiom> axiomBase) Instantiates a newSyntacticLocalityModuleExtractor.