Enum Class LocalityClass
- All Implemented Interfaces:
Serializable,Comparable<LocalityClass>,java.lang.constant.Constable
Types of locality classes that can be used. Note that although these are named after the
syntactic locality classes, when used for the
SemanticLocalityModuleExtractor,
BOTTOM corresponds to \empty_set and TOP corresponds
to \Delta.- Author:
- Marc Robin Nolte
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionLocality module class obtained by giving concepts and roles not present in the signature empty interpretations when extracting a locality based module.Locality module class obtained by giving concepts in the signature top concept interpretation and roles not present universal role interpretation when extracting a locality based module. -
Method Summary
Modifier and TypeMethodDescriptionstatic LocalityClassReturns the enum constant of this class with the specified name.static LocalityClass[]values()Returns an array containing the constants of this enum class, in the order they are declared.Methods inherited from class java.lang.Enum
compareTo, describeConstable, equals, getDeclaringClass, hashCode, name, ordinal, toString, valueOf
-
Enum Constant Details
-
BOTTOM
Locality module class obtained by giving concepts and roles not present in the signature empty interpretations when extracting a locality based module. -
STAR
-
TOP
Locality module class obtained by giving concepts in the signature top concept interpretation and roles not present universal role interpretation when extracting a locality based module.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-